@@ -8,7 +8,7 @@ package Future::AsyncAwait;
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Carp;
 
@@ -157,6 +157,13 @@ should be working:
     }
  }
 
+ async sub wobble
+ {
+    foreach ( THINGs ) {
+       await func();
+    }
+ }
+
 Plain lexical variables are preserved across an C<await> deferral:
 
  async sub quux
@@ -168,16 +175,6 @@ Plain lexical variables are preserved across an C<await> deferral:
 
 =head2 Things That Don't Yet Work
 
-Any code that attempts to C<await> from inside any sort of C<foreach> loop
-does not currently work:
-
- async sub wobble
- {
-    foreach ( THINGs ) {
-       await func();
-    }
- }
-
 C<local> variable assignments inside an C<async> function will confuse the
 suspend mechanism:
 
@@ -231,10 +228,6 @@ sub import_into
 
 =item *
 
-Suspend and resume over C<foreach> loops, in all their various flavours.
-
-=item *
-
 Suspend and resume with some consideration for the savestack; i.e. the area
 used to implement C<local> and similar:
 
